==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-directorymenu/translations/directorymenu_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="120"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Dizin Menü Ayarları</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Temel dizin:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Temel Dizin Adı</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="91"/>
        <source>Choose Base Directory</source>
        <translation>Temel Dizini Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Choose Icon</source>
        <translation>Simge Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="107"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Simgeler (*.png *.xmp *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>Directory Menu</source>
        <translation>Dizin Menüsü</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="116"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Simge yüklenirken hata oluştu.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-directorymenu/translations/directorymenu_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="125"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="129"/>
        <source>Open in terminal</source>
        <translation>Terminal&apos;de aç</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Dizin Menü Ayarları</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Temel dizin:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Temel Dizin Adı</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="73"/>
        <location filename="../directorymenuconfiguration.cpp" line="112"/>
        <source>Choose Default Terminal</source>
        <translation>Varsayılan Terminal&apos;i Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="96"/>
        <source>Choose Base Directory</source>
        <translation>Temel Dizini Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Choose Icon</source>
        <translation>Simge Seç</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Simgeler (*.png *.xmp *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>Directory Menu</source>
        <translation>Dizin Menüsü</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Simge yüklenirken hata oluştu.</translation>
    </message>
</context>
</TS>
